==> react-vuex-0.4.0.tgz: package/es/components/connect.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import { Component, createElement } from 'react';
import PropTypes from 'prop-types';
import hoistStatics from 'hoist-non-react-statics';
import { STORE_KEY } from '../constants';
import shallowEqual from '../utils/shallowEqual';
export default (function (mapStateToPropsFn, mapDispatchToPropsFn, mapCommitToPropsFn, mapGetterToPropsFn) {
  return function (WrappedComponent) {
    var _PresentationalCompon2;

    var PresentationalComponent = /*#__PURE__*/function (_Component) {
      _inherits(PresentationalComponent, _Component);

      var _super = _createSuper(PresentationalComponent);

      function PresentationalComponent(props, context) {
        var _this;

        _classCallCheck(this, PresentationalComponent);

        _this = _super.call(this, props, context);
        _this.store = props[STORE_KEY] || context[STORE_KEY];
        _this.mappedState = mapStateToPropsFn && mapStateToPropsFn(_this.store.state, props);
        _this.mappedGetters = mapGetterToPropsFn && mapGetterToPropsFn(_this.store.getters, props); // will be used to unsubscribe from store changes when the component unmounts

        _this.unsubscribeFn = null;
        _this.state = _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, _this.mappedState), mapDispatchToPropsFn && mapDispatchToPropsFn(_this.store.dispatch, props)), mapCommitToPropsFn && mapCommitToPropsFn(_this.store.commit, props)), _this.mappedGetters);

        if (_this.mappedState) {
          _this.unsubscribeFn = _this.store.subscribe(function (mutation, state) {
            var newState = {}; // update state from store state

            var newMappedState = mapStateToPropsFn(state, _this.props);

            if (!shallowEqual(_this.mappedState, newMappedState)) {
              _this.mappedState = newMappedState;
              newState = _objectSpread(_objectSpread({}, newState), _this.mappedState);
            } // update state from store getters, if any


            if (_this.mappedGetters) {
              var newMappedGetters = mapGetterToPropsFn(_this.store.getters, _this.props);

              if (!shallowEqual(_this.mappedGetters, newMappedGetters)) {
                _this.mappedGetters = newMappedGetters;
                newState = _objectSpread(_objectSpread({}, newState), _this.mappedGetters);
              }
            }

            if (Object.keys(newState).length) {
              _this.setState(newState);
            }
          });
        }

        return _this;
      }

      _createClass(PresentationalComponent, [{
        key: "componentWillUnmount",
        value: function componentWillUnmount() {
          if (typeof this.unsubscribeFn === 'function') {
            this.unsubscribeFn();
          }
        }
      }, {
        key: "render",
        value: function render() {
          return /*#__PURE__*/createElement(WrappedComponent, _objectSpread(_objectSpread({}, this.props), this.state), this.props.children // eslint-disable-line react/destructuring-assignment
          );
        }
      }]);

      return PresentationalComponent;
    }(Component);

    PresentationalComponent.WrappedComponent = WrappedComponent;
    PresentationalComponent.contextTypes = _defineProperty({}, STORE_KEY, PropTypes.object);
    PresentationalComponent.propTypes = (_PresentationalCompon2 = {}, _defineProperty(_PresentationalCompon2, STORE_KEY, PropTypes.object), _defineProperty(_PresentationalCompon2, "children", PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])), _PresentationalCompon2);
    PresentationalComponent.displayName = WrappedComponent.displayName || WrappedComponent.name || 'Component';
    return hoistStatics(PresentationalComponent, WrappedComponent);
  };
});

==> react-vuex-0.4.1.tgz: package/es/components/connect.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import { Component, createElement } from 'react';
import PropTypes from 'prop-types';
import hoistStatics from 'hoist-non-react-statics';
import { STORE_KEY } from '../constants';
import shallowEqual from '../utils/shallowEqual';
export default (function (mapStateToPropsFn, mapDispatchToPropsFn, mapCommitToPropsFn, mapGetterToPropsFn) {
  return function (WrappedComponent) {
    var _PresentationalCompon2;

    var PresentationalComponent = /*#__PURE__*/function (_Component) {
      _inherits(PresentationalComponent, _Component);

      var _super = _createSuper(PresentationalComponent);

      function PresentationalComponent(props, context) {
        var _this;

        _classCallCheck(this, PresentationalComponent);

        _this = _super.call(this, props, context);
        _this.store = props[STORE_KEY] || context[STORE_KEY];
        _this.mappedState = mapStateToPropsFn && mapStateToPropsFn(_this.store.state, props);
        _this.mappedGetters = mapGetterToPropsFn && mapGetterToPropsFn(_this.store.getters, props); // will be used to unsubscribe from store changes when the component unmounts

        _this.unsubscribeFn = null;
        _this.state = _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, _this.mappedState), mapDispatchToPropsFn && mapDispatchToPropsFn(_this.store.dispatch, props)), mapCommitToPropsFn && mapCommitToPropsFn(_this.store.commit, props)), _this.mappedGetters);

        if (_this.mappedState || _this.mappedGetters) {
          _this.unsubscribeFn = _this.store.subscribe(function (mutation, state) {
            var newState = {}; // update state from store state

            var newMappedState = mapStateToPropsFn && mapStateToPropsFn(state, _this.props);

            if (!shallowEqual(_this.mappedState, newMappedState)) {
              _this.mappedState = newMappedState;
              newState = _objectSpread(_objectSpread({}, newState), _this.mappedState);
            } // update state from store getters, if any


            if (_this.mappedGetters) {
              var newMappedGetters = mapGetterToPropsFn && mapGetterToPropsFn(_this.store.getters, _this.props);

              if (!shallowEqual(_this.mappedGetters, newMappedGetters)) {
                _this.mappedGetters = newMappedGetters;
                newState = _objectSpread(_objectSpread({}, newState), _this.mappedGetters);
              }
            }

            if (Object.keys(newState).length) {
              _this.setState(newState);
            }
          });
        }

        return _this;
      }

      _createClass(PresentationalComponent, [{
        key: "componentWillUnmount",
        value: function componentWillUnmount() {
          if (typeof this.unsubscribeFn === 'function') {
            this.unsubscribeFn();
          }
        }
      }, {
        key: "render",
        value: function render() {
          return /*#__PURE__*/createElement(WrappedComponent, _objectSpread(_objectSpread({}, this.props), this.state), this.props.children // eslint-disable-line react/destructuring-assignment
          );
        }
      }]);

      return PresentationalComponent;
    }(Component);

    PresentationalComponent.WrappedComponent = WrappedComponent;
    PresentationalComponent.contextTypes = _defineProperty({}, STORE_KEY, PropTypes.object);
    PresentationalComponent.propTypes = (_PresentationalCompon2 = {}, _defineProperty(_PresentationalCompon2, STORE_KEY, PropTypes.object), _defineProperty(_PresentationalCompon2, "children", PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])), _PresentationalCompon2);
    PresentationalComponent.displayName = WrappedComponent.displayName || WrappedComponent.name || 'Component';
    return hoistStatics(PresentationalComponent, WrappedComponent);
  };
});
